@@ -23,13 +23,13 @@ joss_article <- function(journal = "JOSS",
 
   rmarkdown::pandoc_available('2.2', TRUE)
 
-  logo_path <- find_resource("joss_article", paste0(journal, "-logo.png"))
+  logo_path <- find_resource("joss", paste0(journal, "-logo.png"))
   journalname <- ifelse(journal == "JOSS",
                         "Journal of Open Source Software",
                         "Journal of Open Source Education")
 
   pdf_document_format(
-    "joss_article",
+    "joss",
     latex_engine = latex_engine,
     citation_package = "none",
     keep_md = keep_md,
